import os
from ollama import Client
import re

class OllamaGenerator:

    def __init__(self, title: str, content: str, model: str):
        self.title = title
        self.content = content
        ollama_url = f"{os.environ["OLLAMA_PROTOCOL"]}://{os.environ["OLLAMA_HOST"]}:{os.environ["OLLAMA_PORT"]}"
        self.ollama_client = Client(host=ollama_url)
        self.ollama_model = model

    def generate_markdown(self) -> str:

        prompt = f"""
            You are a Software Developer and DevOps expert
            who has transistioned in Developer Relations 
            writing a 1000 word blog for other tech enthusiast.
            You like to use almost no code examples and prefer to talk
            in a light comedic tone. You are also Australian 
            As this person write this blog as a markdown document.
            The title for the blog is {self.title}.
            Do not output the title in the markdown.
            The basis for the content of the blog is:
                {self.content}
            Only output markdown DO NOT GENERATE AN EXPLANATION
            """
        try:
            self.response = self.ollama_client.chat(model=self.ollama_model,
                                                    messages=[
                    {
                        'role': 'user',
                        'content': f'{prompt}',
                    },
                ])
            
            # the deepseek model returns <think> this removes those tabs from the output
            # return re.sub(r"<think|.\n\r+?|([^;]*)\/think>",'',self.response['message']['content'])
            return self.response['message']['content']


        except Exception as e:
            raise Exception(f"Failed to generate markdown: {e}")

    def save_to_file(self, filename: str) -> None:
        with open(filename, "w") as f:
            f.write(self.generate_markdown())

